<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=uk
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Фільтри для обробки зображень і роботи з кольорами',
	'images_slogan' => 'Фільтри для обробки зображень і роботи з кольорами',
];
